"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getValidatorFn = void 0;
const ts_type_safety_utils_1 = require("@nerdware/ts-type-safety-utils");
/**
 * Returns a {@link ValidatorFn} which takes an unknown input, and returns
 * `true` if the input is a string that matches the provided regex pattern(s).
 */
const getValidatorFn = (
/** One or more `RegExp` patterns. */
regexArg, 
/** A fn which returns `true` if `value` is of the expected type (default: {@link isString}). */
isExpectedType = ts_type_safety_utils_1.isString) => {
    return Array.isArray(regexArg)
        ? (value) => {
            return isExpectedType(value) && regexArg.every((regex) => regex.test(value));
        }
        : (value) => {
            return isExpectedType(value) && regexArg.test(value);
        };
};
exports.getValidatorFn = getValidatorFn;
