/**
 * Regex used to test if a value conforms to the official RFC-5322 email address format.
 *
 * ### Limitations
 * - This regex pattern does NOT check the entire length of the string.
 * - This regex pattern does NOT check for banned characters like zero-width spaces.
 * > To address these limitations, use {@link EMAIL_VALIDATION_REGEX}.
 */
export declare const EMAIL_RFC_5322_VALIDATION_REGEX: RegExp;
/**
 * Regex used to validate email address strings. This pattern enforces the following rules:
 *
 * - The value does not begin with a period, and does not contain 2+ consecutive periods.
 * - The number of characters before the `@` is between 1-64.
 * - The number of characters after the `@` is between 1-255.
 * - The substring before the `@` only contains alphanumeric characters or . _ % + -
 * - The substring after the `@` only contains alphanumeric characters or . _
 * - The TLD only contains letters, and is between 2-64 characters in length.
 *
 * ### Limitations
 * - This regex pattern does NOT enforce the official RFC-5322 email address format.
 * > To address these limitations, use {@link EMAIL_RFC_5322_VALIDATION_REGEX}.
 */
export declare const EMAIL_VALIDATION_REGEX: RegExp;
/**
 * Returns `true` if `value` is a valid email address.
 */
export declare const isValidEmail: import("../utils/getValidatorFn.js").ValidatorFn;
